@@ -31,6 +31,8 @@ type SQLiteState struct {
 }
 
 const (
+	// Name of the actual database file
+	sqliteDbFilename = "db.sql"
 	// Deal with timezone automatically.
 	sqliteOptionLocation = "_loc=auto"
 	// Force an fsync after each transaction (https://www.sqlite.org/pragma.html#pragma_synchronous).
@@ -43,7 +45,7 @@ const (
 	sqliteOptionCaseSensitiveLike = "&_cslike=TRUE"
 
 	// Assembled sqlite options used when opening the database.
-	sqliteOptions = "db.sql?" +
+	sqliteOptions = sqliteDbFilename + "?" +
 		sqliteOptionLocation +
 		sqliteOptionSynchronous +
 		sqliteOptionForeignKeys +
@@ -56,12 +58,7 @@ func NewSqliteState(runtime *Runtime) (_ State, defErr error) {
 	logrus.Info("Using sqlite as database backend")
 	state := new(SQLiteState)
 
-	basePath := runtime.storageConfig.GraphRoot
-	if runtime.storageConfig.TransientStore {
-		basePath = runtime.storageConfig.RunRoot
-	} else if !runtime.storageSet.StaticDirSet {
-		basePath = runtime.config.Engine.StaticDir
-	}
+	basePath, _ := sqliteStatePath(runtime)
 
 	// c/storage is set up *after* the DB - so even though we use the c/s
 	// root (or, for transient, runroot) dir, we need to make the dir
@@ -276,6 +273,10 @@ func (s *SQLiteState) Refresh() (defErr error) {
 	return nil
 }
 
+func (s *SQLiteState) Type() string {
+	return "sqlite"
+}
+
 // GetDBConfig retrieves runtime configuration fields that were created when
 // the database was first initialized
 func (s *SQLiteState) GetDBConfig() (*DBConfig, error) {
@@ -316,8 +317,10 @@ func (s *SQLiteState) ValidateDBConfig(_ *Runtime) (defErr error) {
 		return err
 	}
 
+	// Ignoring prevents a race condition where multiple Podman processes
+	// might try to initialize the database at the same time.
 	const createRow = `
-        INSERT INTO DBconfig VALUES (
+        INSERT OR IGNORE INTO DBconfig VALUES (
                 ?, ?, ?,
                 ?, ?, ?,
                 ?, ?, ?
